@@ -3,8 +3,8 @@
 ;; Copyright (C) 2013-2026  Thierry Banel
 
 ;; Author: Thierry Banel  tbanelwebmin at free dot fr
-;; Package-Version: 20260122.1125
-;; Package-Revision: b4e5098ec0ab
+;; Package-Version: 20260126.1121
+;; Package-Revision: e9583daf44a9
 ;; Keywords: org, table, ascii, plot
 
 ;; orgtbl-ascii-plot is free software: you can redistribute it and/or modify
@@ -200,6 +200,10 @@ Examples:
        eos)
       x))
     (string-to-number x))
+   ((and
+     (stringp x)
+     (string-match org-ts-regexp0 x))
+    (org-time-string-to-seconds x))
    (t nil)))
 
 ;;╭────────────────────╮
